==> upload-api-client-internal-2.55.0.tgz: package/src/services/AdminService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { EmailAddress } from "../models/EmailAddress";
import type { SubscriptionPlan } from "../models/SubscriptionPlan";
import type { UserAccountListItem } from "../models/UserAccountListItem";
import type { UserId } from "../models/UserId";
import { request as __request } from "../core/request";

export class AdminService {
  /**
   * Looks up information for a user by their email address.
   * @param email
   * @returns UserAccountListItem Success.
   * @throws ApiError
   */
  public static async lookupEmailAddress(email: EmailAddress): Promise<Array<UserAccountListItem>> {
    const result = await __request({
      method: "GET",
      path: `/v1/admin/accounts/by_email`,
      query: {
        email: email
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Looks up information for a user by their user ID.
   * @param userId
   * @returns UserAccountListItem Success.
   * @throws ApiError
   */
  public static async lookupUserId(userId: UserId): Promise<Array<UserAccountListItem>> {
    const result = await __request({
      method: "GET",
      path: `/v1/admin/accounts/by_user_id`,
      query: {
        userId: userId
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Looks up information for an account by its account ID.
   * @param accountId
   * @returns UserAccountListItem Success.
   * @throws ApiError
   */
  public static async lookupAccountId(accountId: AccountId): Promise<UserAccountListItem> {
    const result = await __request({
      method: "GET",
      path: `/v1/admin/accounts/by_account_id`,
      query: {
        accountId: accountId
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Disables the user's access, deletes their files, and purges the CDN.
   * @param accountId
   * @returns void
   * @throws ApiError
   */
  public static async purgeAccount(accountId: AccountId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/admin/accounts/${accountId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Set account limits.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async setAccountLimits(accountId: AccountId, requestBody: SubscriptionPlan): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/admin/accounts/${accountId}/limits`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-2.71.0.tgz: package/src/services/AdminService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { EmailAddress } from "../models/EmailAddress";
import type { SetAccountPlan } from "../models/SetAccountPlan";
import type { UserAccountListItem } from "../models/UserAccountListItem";
import type { UserId } from "../models/UserId";
import { request as __request } from "../core/request";

export class AdminService {
  /**
   * Looks up information for a user by their email address.
   * @param email
   * @returns UserAccountListItem Success.
   * @throws ApiError
   */
  public static async lookupEmailAddress(email: EmailAddress): Promise<Array<UserAccountListItem>> {
    const result = await __request({
      method: "GET",
      path: `/v1/admin/accounts/by_email`,
      query: {
        email: email
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Looks up information for a user by their user ID.
   * @param userId
   * @returns UserAccountListItem Success.
   * @throws ApiError
   */
  public static async lookupUserId(userId: UserId): Promise<Array<UserAccountListItem>> {
    const result = await __request({
      method: "GET",
      path: `/v1/admin/accounts/by_user_id`,
      query: {
        userId: userId
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Looks up information for an account by its account ID.
   * @param accountId
   * @returns UserAccountListItem Success.
   * @throws ApiError
   */
  public static async lookupAccountId(accountId: AccountId): Promise<UserAccountListItem> {
    const result = await __request({
      method: "GET",
      path: `/v1/admin/accounts/by_account_id`,
      query: {
        accountId: accountId
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Disables the user's access, deletes their files, and purges the CDN.
   * @param accountId
   * @returns void
   * @throws ApiError
   */
  public static async purgeAccount(accountId: AccountId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/admin/accounts/${accountId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Set account limits.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async setAccountPlan(accountId: AccountId, requestBody: SetAccountPlan): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/admin/accounts/${accountId}/plan`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
